export declare enum HTTPStatusCode {
    SUCCESS = "200",
    PAGE_NOT_FOUND = "404",
    ACCESS_FORBIDDEN = "403"
}
export declare enum AuthStatus {
    LOGGED_IN = 0,
    NOT_LOGGED_IN = 1
}
export declare enum HTTPRequestType {
    GET = "GET",
    POST = "POST"
}
export interface KatrineActionInterface {
    addAccessRule(rule: AccessRuleInterface): any;
    canAccess(req: any): boolean;
    getRoute(): string;
    getActionMethodName(): string;
    getRequestType(): HTTPRequestType;
    getController(): any;
    setController(controller: any): void;
    getControllerName(): string;
    setInvoker(boundMehtod: any): void;
    invoke(...args: any[]): any;
    /**
     * Returns original controller without bindngs
     */
    getControllerClass(): any;
}
/**
 * Main interface that describes all project annotations
 */
export interface ProjectMetadataInterface {
    hasAnyActions(): boolean;
    getActionByRoute(route: string): KatrineActionInterface;
    storeAction(action: KatrineActionInterface): any;
    getActions(): KatrineActionInterface[];
    addController(controllerName: string, controller: any): any;
    addAccessByRoleRule(ruleData: AccessTypeable, actionName: string, controller: any): any;
}
/**
 * Base interface for any rules with the Katrine
 */
export default interface AccessRuleInterface {
    canAccess(req: any): boolean;
}
export declare enum AccessRulesType {
    ByRole = "role",
    ByAuth = "auth"
}
export declare type AccessTypeable = {
    type: AccessRulesType;
};
export declare type AccessByRoleData = AccessTypeable & {
    roles: string | string[];
};
export declare type AccessByAuthData = AccessTypeable & {
    auth: AuthStatus;
};
