"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const pug = require('pug');
class KatrineController {
    constructor() {
        this.cachedViews = new Map();
        this.cachedLayoutViews = new Map();
    }
    getLayout() {
        return '';
    }
    getPugViewTemplate(viewPath) {
        if (!this.cachedViews.has(viewPath)) {
            const view = pug.compileFile(viewPath);
            this.cachedViews.set(viewPath, view);
        }
        return this.cachedViews.get(viewPath);
    }
    getPugLayoutTemplate(layoutName) {
        if (!this.cachedLayoutViews.has(layoutName)) {
            const view = pug.compileFile(layoutName);
            this.cachedLayoutViews.set(layoutName, view);
        }
        return this.cachedLayoutViews.get(layoutName);
    }
    render(viewPath, params = {}) {
        const template = this.getPugViewTemplate(viewPath);
        const renderedActionContent = template(params);
        const layout = this.getLayout();
        if (layout) {
            return this.finallRender(renderedActionContent, layout, params);
        }
        return renderedActionContent;
    }
    renderString(content, params = {}) {
        const layout = this.getLayout();
        if (layout) {
            return this.finallRender(content, layout, params);
        }
        return content;
    }
    renderLayout(viewPath, layoutPath, params) {
        const template = this.getPugViewTemplate(viewPath);
        const renderedActionContent = template(params);
        return this.finallRender(renderedActionContent, layoutPath, params);
    }
    finallRender(content, layout, params = {}) {
        const template = this.getPugLayoutTemplate(layout);
        return template(Object.assign({ content }, params));
    }
}
exports.default = KatrineController;
