"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _types_1 = require("./@types");
const KatrineAction_1 = require("./metadata/KatrineAction");
const ProjectMetadata_1 = require("./metadata/ProjectMetadata");
/**
 * Marks handler(function) in controller as action
 *
 * @param route - Express compatible router
 * @param method - POST/GET that will be bind
 */
function action(route, method = _types_1.HTTPRequestType.GET) {
    return function (controller, actionMethod, descriptor) {
        const action = new KatrineAction_1.default(route, actionMethod, method, controller);
        ProjectMetadata_1.default.storeAction(action);
    };
}
exports.action = action;
function controller(controllerClass) {
    ProjectMetadata_1.default.addController(controllerClass.name, controllerClass);
}
exports.controller = controller;
exports.accessByRole = (roles) => {
    return function (controller, actionMethod, descriptor) {
        const ruleData = {
            type: _types_1.AccessRulesType.ByRole,
            roles
        };
        ProjectMetadata_1.default.addAccessByRoleRule(ruleData, actionMethod, controller);
    };
};
exports.accessByAuth = (auth = _types_1.AuthStatus.LOGGED_IN) => {
    return function (controller, actionMethod, descriptor) {
        const ruleData = {
            type: _types_1.AccessRulesType.ByAuth,
            auth
        };
        ProjectMetadata_1.default.addAccessByRoleRule(ruleData, actionMethod, controller);
    };
};
